@@ -3,10 +3,18 @@
 import '@patternfly/react-core/dist/styles/base.css'
 import React, { Fragment, useReducer, useEffect, useState } from 'react'
 import { ButtonVariant, ModalVariant } from '@patternfly/react-core'
-import { AcmModal, AcmButton, AcmForm, AcmTextInput, AcmTextArea, AcmAlert } from '@stolostron/ui-components'
+import {
+    AcmModal,
+    AcmButton,
+    AcmForm,
+    AcmTextInput,
+    AcmTextArea,
+    AcmAlert,
+} from '@open-cluster-management/ui-components'
 import { useTranslation } from 'react-i18next'
-import { SavedSearchesDocument, useSaveSearchMutation } from '../../../../search-sdk/search-sdk'
+import { SavedSearchesDocument, useSaveSearchMutation, UserSearch } from '../../../../search-sdk/search-sdk'
 import { searchClient } from '../../../../search-sdk/search-client'
+import SuggestQueryTemplates from '../SuggestedQueryTemplates'
 import { makeStyles } from '@material-ui/styles'
 
 type IState = {
@@ -36,16 +44,23 @@ export const SaveAndEditSearchModal = (props: any) => {
     const { searchName, searchDesc } = state
     const [saveSearchMutation, { error }] = useSaveSearchMutation({ client: searchClient })
     const [isError, setIsError] = useState<boolean>(false)
+    const [isNameConflict, setIsNameConflict] = useState<boolean>(false)
     const classes = useStyles()
 
     useEffect(() => {
         dispatch({ field: 'searchName', value: props.editSearch?.name ?? '' })
         dispatch({ field: 'searchDesc', value: props.editSearch?.description ?? '' })
+        return () => {
+            setIsNameConflict(false)
+        }
     }, [props.editSearch])
 
     useEffect(() => {
         dispatch({ field: 'searchName', value: '' })
         dispatch({ field: 'searchDesc', value: '' })
+        return () => {
+            setIsNameConflict(false)
+        }
     }, [props.saveSearch])
 
     function reducer(state: IState, { field, value }: ActionType) {
@@ -56,6 +71,18 @@ export const SaveAndEditSearchModal = (props: any) => {
     }
 
     function onChange(value: string, e: React.FormEvent<HTMLInputElement> | React.ChangeEvent<HTMLTextAreaElement>) {
+        const suggestedQueryTemplates = SuggestQueryTemplates?.templates ?? ([] as UserSearch[])
+        const allSavedQueryNames = [...suggestedQueryTemplates, ...props.savedSearchQueries].map(
+            (savedQuery: UserSearch) => savedQuery.name?.toLowerCase() || ''
+        )
+        if (
+            allSavedQueryNames.includes(value.toLowerCase()) &&
+            props.editSearch?.name.toLowerCase() !== value.toLowerCase()
+        ) {
+            setIsNameConflict(true)
+        } else if (isNameConflict) {
+            setIsNameConflict(false)
+        }
         dispatch({ field: e.currentTarget.name, value: value })
     }
 
@@ -84,7 +111,7 @@ export const SaveAndEditSearchModal = (props: any) => {
     }
 
     const isSubmitDisabled = () => {
-        return state.searchName === '' || (!props.editSearch && props.saveSearch === '')
+        return state.searchName === '' || (!props.editSearch && props.saveSearch === '') || isNameConflict
     }
 
     return (
@@ -119,6 +146,14 @@ export const SaveAndEditSearchModal = (props: any) => {
                     />
                 )}
                 {isError && <AcmAlert noClose variant={'danger'} title={error!.message} />}
+                {isNameConflict && (
+                    <AcmAlert
+                        isInline
+                        noClose
+                        variant={'warning'}
+                        title={t('search.modal.save.name.conflict.error', { searchName })}
+                    />
+                )}
                 <AcmForm>
                     <AcmTextInput
                         id="add-query-name"
