@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.es", {
 		"Habilita las sugerencias de incrustación en el editor.",
 		"Controla el tamaño de la fuente de las sugerencias de incrustación en el editor. Cuando se establece en \"0\", se utiliza el 90% de \"#editor.fontSize#\".",
 		"Controla la familia de fuentes de las sugerencias de incrustación en el editor.",
-		"Controla la altura de línea. Usa 0 para utilizar la altura del tamaño de fuente.",
+		"Controla el alto de línea. \r\n - Use 0 para calcular automáticamente el alto de línea a partir del tamaño de la fuente.\r\n - Los valores entre 0 y 8 se usarán como multiplicador con el tamaño de fuente.\r\n - Los valores mayores o igual que 8 se usarán como valores efectivos.",
 		"Controla si se muestra el minimapa.",
 		"El minimapa tiene el mismo tamaño que el contenido del editor (y podría desplazarse).",
 		"El minimapa se estirará o reducirá según sea necesario para ocupar la altura del editor (sin desplazamiento).",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.es", {
 		"Número de caracteres monoespaciales en los que se representará esta regla del editor.",
 		"Color de esta regla del editor.",
 		"Muestra reglas verticales después de un cierto número de caracteres monoespaciados. Usa múltiples valores para mostrar múltiples reglas. Si la matriz está vacía, no se muestran reglas.",
+		"La barra de desplazamiento vertical estará visible solo cuando sea necesario.",
+		"La barra de desplazamiento vertical estará siempre visible.",
+		"La barra de desplazamiento vertical estará siempre oculta.",
+		"Controla la visibilidad de la barra de desplazamiento vertical.",
+		"La barra de desplazamiento horizontal estará visible solo cuando sea necesario.",
+		"La barra de desplazamiento horizontal estará siempre visible.",
+		"La barra de desplazamiento horizontal estará siempre oculta.",
+		"Controla la visibilidad de la barra de desplazamiento horizontal.",
+		"Ancho de la barra de desplazamiento vertical.",
+		"Altura de la barra de desplazamiento horizontal.",
+		"Controla si al hacer clic se desplaza por página o salta a la posición donde se hace clic.",
 		"Controla si se deben mostrar automáticamente las sugerencias alineadas en el editor.",
+		"Representar solo una sugerencia alineada si el texto de reemplazo es un prefijo del texto de inserción.",
+		"Representar solo una sugerencia alineada si el texto de reemplazo es una subpalabra del texto de inserción.",
+		"Controla el modo que se va a usar para representar sugerencias alineadas.",
 		"Inserte la sugerencia sin sobrescribir el texto a la derecha del cursor.",
 		"Inserte la sugerencia y sobrescriba el texto a la derecha del cursor.",
 		"Controla si las palabras se sobrescriben al aceptar la finalización. Tenga en cuenta que esto depende de las extensiones que participan en esta característica.",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.es", {
 		"Controla si mostrar u ocultar iconos en sugerencias.",
 		"Controla la visibilidad de la barra de estado en la parte inferior del widget de sugerencias.",
 		"Controla si se puede obtener una vista previa del resultado de la sugerencia en el editor.",
+		"Representar solo una vista previa si el texto de reemplazo es un prefijo del texto de inserción.",
+		"Representar solo una vista previa si el texto de reemplazo es una subpalabra del texto de inserción.",
+		"Controla el modo que se va a usar para representar la vista previa de sugerencias.",
 		"Controla si los detalles de sugerencia se muestran incorporados con la etiqueta o solo en el widget de detalles.",
 		"La configuración está en desuso. Ahora puede cambiarse el tamaño del widget de sugerencias.",
 		"Esta configuración está en desuso. Use configuraciones separadas como \"editor.suggest.showKeyword\" o \"editor.suggest.showSnippets\" en su lugar.",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.es", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"Cargando...",
+		"Por motivos de rendimiento, la tokenización se omite con filas largas. Esta opción se puede configurar con \"editor.maxTokenizationLineLength\".",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"Ver el problema",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.es", {
 		"Color de borde del widget sugerido.",
 		"Color de primer plano del widget sugerido.",
 		"Color de primer plano de le entrada seleccionada del widget de sugerencias.",
+		"Color de primer plano del icono de la entrada seleccionada en el widget de sugerencias.",
 		"Color de fondo de la entrada seleccionada del widget sugerido.",
 		"Color del resaltado coincidido en el widget sugerido.",
 		"Color de los resaltados de coincidencia en el widget de sugerencias cuando se enfoca un elemento.",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.es", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"Terminadores de línea inusuales",
 		"Se han detectado terminadores de línea inusuales",
-		"Este archivo contiene uno o más caracteres de terminación de línea inusuales, como el separador de línea (LS) o el separador de párrafo (PS).\r\n\r\nSe recomienda eliminarlos del archivo. Esto puede configurarse mediante \"editor.unusualLineTerminators\".",
-		"Corregir este archivo",
-		"Ignorar problema para este archivo",
+		"Este archivo \"{0}\" contiene uno o más caracteres de terminación de línea inusuales, como el separador de línea (LS) o el separador de párrafo (PS).\r\n\r\nSe recomienda eliminarlos del archivo. Esto puede configurarse mediante \"editor.unusualLineTerminators\".",
+		"Quitar terminadores de línea inusuales",
+		"Omitir",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"Color de fondo de un símbolo durante el acceso de lectura, como la lectura de una variable. El color no debe ser opaco para no ocultar decoraciones subyacentes.",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.es", {
 		"usado recientemente",
 		"otros comandos",
 		"El comando \"{0}\" dio lugar a un error ({1})",
-		"Aceptar",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"comandos globales",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.es", {
 		"Un borde adicional alrededor de los elementos para separarlos unos de otros y así mejorar el contraste.",
 		"Un borde adicional alrededor de los elementos activos para separarlos unos de otros y así mejorar el contraste.",
 		"Color de primer plano para los vínculos en el texto.",
+		"Color de primer plano para los enlaces de texto, al hacer clic o pasar el mouse sobre ellos.",
 		"Color de fondo para los bloques de código en el texto.",
 		"Color de sombra de los widgets dentro del editor, como buscar/reemplazar",
 		"Fondo de cuadro de entrada.",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.es", {
 		"Color de contorno de la lista o el árbol del elemento con el foco cuando la lista o el árbol están activos. Una lista o un árbol tienen el foco del teclado cuando están activos, pero no cuando están inactivos.",
 		"Color de fondo de la lista o el árbol del elemento seleccionado cuando la lista o el árbol están activos. Una lista o un árbol tienen el foco del teclado cuando están activos, cuando están inactivos no.",
 		"Color de primer plano de la lista o el árbol del elemento seleccionado cuando la lista o el árbol están activos. Una lista o un árbol tienen el foco del teclado cuando están activos, cuando están inactivos no.",
+		"Color de primer plano del icono de lista o árbol del elemento seleccionado cuando la lista o el árbol están activos. Una lista o un árbol tienen el foco del teclado cuando están activos, cuando están inactivos no.",
 		"Color de fondo de la lista o el árbol del elemento seleccionado cuando la lista o el árbol están inactivos. Una lista o un árbol tienen el foco del teclado cuando están activos, cuando están inactivos no.",
 		"Color de primer plano de la lista o el árbol del elemento con el foco cuando la lista o el árbol esta inactiva. Una lista o un árbol tiene el foco del teclado cuando está activo, cuando esta inactiva no.",
+		"Color de primer plano del icono de lista o árbol del elemento seleccionado cuando la lista o el árbol están inactivos. Una lista o un árbol tienen el foco del teclado cuando están activos, cuando están inactivos no.",
 		"Color de fondo de la lista o el árbol del elemento con el foco cuando la lista o el árbol están inactivos. Una lista o un árbol tienen el foco del teclado cuando están activos, pero no cuando están inactivos.",
 		"Color de contorno de la lista o el árbol del elemento con el foco cuando la lista o el árbol están inactivos. Una lista o un árbol tienen el foco del teclado cuando están activos, pero no cuando están inactivos.",
 		"Fondo de la lista o el árbol al mantener el mouse sobre los elementos.",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.es", {
 		"Color de trazo de árbol para las guías de sangría.",
 		"Use quickInputList.focusBackground en su lugar.",
 		"Selector rápido del color de primer plano para el elemento con el foco.",
+		"Color de primer plano del icono del selector rápido para el elemento con el foco.",
 		"Color de fondo del selector rápido para el elemento con el foco.",
 		"Color del borde de los menús.",
 		"Color de primer plano de los elementos de menú.",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.es", {
 		"Cancelar",
 		"No se pudo deshacer \"{0}\" porque ya hay una operación de deshacer o rehacer en ejecución.",
 		"¿Quiere deshacer \"{0}\"?",
-		"Deshacer",
+		"Sí",
 		"Cancelar",
 		"No se pudo rehacer \"{0}\" en todos los archivos. {1}",
 		"No se pudo rehacer \"{0}\" en todos los archivos. {1}",
