@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"在编辑器中启用内联提示。",
 		"控制在编辑器中内联提示的字号。设置为 `0` 时，将使用 `#editor.fontSize#` 的 90%。",
 		"在编辑器中控制内联提示的字体系列。",
-		"控制行高。为 0 时则通过字体大小自动计算。",
+		"控制行高。\r\n - 使用 0 根据字号自动计算行高。\r\n - 介于 0 和 8 之间的值将用作字号的乘数。\r\n - 大于或等于 8 的值将用作有效值。",
 		"控制是否显示缩略图。",
 		"迷你地图的大小与编辑器内容相同(并且可能滚动)。",
 		"迷你地图将根据需要拉伸或缩小以填充编辑器的高度(不滚动)。",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"此编辑器标尺将渲染的等宽字符数。",
 		"此编辑器标尺的颜色。",
 		"在一定数量的等宽字符后显示垂直标尺。输入多个值，显示多个标尺。若数组为空，则不绘制标尺。",
+		"垂直滚动条仅在必要时可见。",
+		"垂直滚动条将始终可见。",
+		"垂直滚动条将始终隐藏。",
+		"控制垂直滚动条的可见性。",
+		"水平滚动条仅在必要时可见。",
+		"水平滚动条将始终可见。",
+		"水平滚动条将始终隐藏。",
+		"控制水平滚动条的可见性。",
+		"垂直滚动条的宽度。",
+		"水平滚动条的高度。",
+		"控制单击按页滚动还是跳转到单击位置。",
 		"控制是否在编辑器中自动显示内联建议。",
+		"仅当替换文本是插入文本的前缀时才呈现内联建议。",
+		"仅当替换文本是插入文本的字词时才呈现内联建议。",
+		"控制使用何种模式呈现内联建议。",
 		"插入建议而不覆盖光标右侧的文本。",
 		"插入建议并覆盖光标右侧的文本。",
 		"控制接受补全时是否覆盖单词。请注意，这取决于扩展选择使用此功能。",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"控制是否在建议中显示或隐藏图标。",
 		"控制建议小部件底部的状态栏的可见性。",
 		"控制是否在编辑器中预览建议结果。",
+		"仅当替换文本是插入文本的前缀时才呈现预览。",
+		"仅当替换文本是插入文本的子词时才呈现预览。",
+		"控制用于呈现建议预览的模式。",
 		"控制建议详细信息是随标签一起显示还是仅显示在详细信息小组件中",
 		"此设置已弃用。现在可以调整建议小组件的大小。",
 		"此设置已弃用，请改用单独的设置，如\"editor.suggest.showKeywords\"或\"editor.suggest.showSnippets\"。",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"正在加载...",
+		"出于性能原因，对长行跳过令牌化。这可以通过 “editor.maxTokenizationLineLength” 进行配置。",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"查看问题",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"建议小组件的边框颜色。",
 		"建议小组件的前景色。",
 		"建议小组件中所选条目的前景色。",
+		"建议小组件中所选条目的图标前景色。",
 		"建议小组件中所选条目的背景色。",
 		"建议小组件中匹配内容的高亮颜色。",
 		"当某项获得焦点时，在建议小组件中突出显示的匹配项的颜色。",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.zh-cn", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"异常行终止符",
 		"检测到异常行终止符",
-		"此文件包含一个或多个异常的行终止符，例如行分隔符(LS)或段落分隔符(PS)。\r\n\r\n建议从文件中删除它们。可通过 \"editor.unusualLineTerminators\" 进行配置。",
-		"修复此文件",
-		"忽略此文件的问题",
+		"文件“{0}”包含一个或多个异常的行终止符，例如行分隔符(LS)或段落分隔符(PS)。\r\n\r\n建议从文件中删除它们。可通过“editor.unusualLineTerminators”进行配置。",
+		"删除异常行终止符",
+		"忽略",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"读取访问期间符号的背景色，例如读取变量时。颜色必须透明，以免隐藏下面的修饰效果。",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"最近使用",
 		"其他命令",
 		"命令\"{0}\"导致错误 ({1})",
-		"确定",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"全局命令",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"在元素周围额外的一层边框，用来提高对比度从而区别其他元素。",
 		"在活动元素周围额外的一层边框，用来提高对比度从而区别其他元素。",
 		"文本中链接的前景色。",
+		"文本中链接在点击或鼠标悬停时的前景色 。",
 		"文本中代码块的背景颜色。",
 		"编辑器内小组件(如查找/替换)的阴影颜色。",
 		"输入框背景色。",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"列表/树活动时，焦点项目的列表/树边框色。活动的列表/树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树活动时的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树活动时的前景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
+		"已选项在列表/树活动时的列表/树图标前景颜色。活动的列表/树具有键盘焦点，非活动的则没有。",
 		"已选项在列表或树非活动时的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"已选项在列表或树非活动时的前景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
+		"已选项在列表/树非活动时的图标前景颜色。活动的列表/树具有键盘焦点，非活动的则没有。",
 		"非活动的列表或树控件中焦点项的背景颜色。活动的列表或树具有键盘焦点，非活动的没有。",
 		"列表/数非活动时，焦点项目的列表/树边框色。活动的列表/树具有键盘焦点，非活动的没有。",
 		"使用鼠标移动项目时，列表或树的背景颜色。",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"缩进参考线的树描边颜色。",
 		"请改用 quickInputList.focusBackground",
 		"焦点项目的快速选择器前景色。",
+		"焦点项目的快速选取器图标前景色。",
 		"焦点项目的快速选择器背景色。",
 		"菜单的边框颜色。",
 		"菜单项的前景颜色。",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.zh-cn", {
 		"取消",
 		"无法撤销“{0}”，因为已有一项撤消或重做操作正在运行。",
 		"是否要撤消“{0}”?",
-		"撤消",
+		"是",
 		"取消",
 		"无法在所有文件中重做“{0}”。{1}",
 		"无法在所有文件中重做“{0}”。{1}",
