@@ -26,7 +26,7 @@ import * as platform from '../../../common/platform.js';
 import { Gesture } from '../../touch.js';
 import { StandardKeyboardEvent } from '../../keyboardEvent.js';
 import { Event, Emitter, EventBufferer } from '../../../common/event.js';
-import { domEvent, stopEvent } from '../../event.js';
+import { DomEmitter, stopEvent } from '../../event.js';
 import { ListError } from './list.js';
 import { ListView } from './listView.js';
 import { Color } from '../../../common/color.js';
@@ -94,6 +94,7 @@ class TraitRenderer {
 class Trait {
     constructor(_trait) {
         this._trait = _trait;
+        this.length = 0;
         this.indexes = [];
         this.sortedIndexes = [];
         this._onChange = new Emitter();
@@ -104,15 +105,23 @@ class Trait {
         return new TraitRenderer(this);
     }
     splice(start, deleteCount, elements) {
+        var _a;
+        deleteCount = Math.max(0, Math.min(deleteCount, this.length - start));
         const diff = elements.length - deleteCount;
         const end = start + deleteCount;
-        const indexes = [
+        const sortedIndexes = [
             ...this.sortedIndexes.filter(i => i < start),
             ...elements.map((hasTrait, i) => hasTrait ? i + start : -1).filter(i => i !== -1),
             ...this.sortedIndexes.filter(i => i >= end).map(i => i + diff)
         ];
+        const length = this.length + diff;
+        if (this.sortedIndexes.length > 0 && sortedIndexes.length === 0 && length > 0) {
+            const first = (_a = this.sortedIndexes.find(index => index >= start)) !== null && _a !== void 0 ? _a : length - 1;
+            sortedIndexes.push(Math.min(first, length - 1));
+        }
         this.renderer.splice(start, deleteCount, elements.length);
-        this._set(indexes, indexes);
+        this._set(sortedIndexes, sortedIndexes);
+        this.length = length;
     }
     renderIndex(index, container) {
         container.classList.toggle(this._trait, this.contains(index));
@@ -209,18 +218,28 @@ class KeyboardController {
         this.list = list;
         this.view = view;
         this.disposables = new DisposableStore();
-        const multipleSelectionSupport = options.multipleSelectionSupport !== false;
-        const onKeyDown = Event.chain(domEvent(view.domNode, 'keydown'))
+        this.multipleSelectionDisposables = new DisposableStore();
+        this.onKeyDown.filter(e => e.keyCode === 3 /* Enter */).on(this.onEnter, this, this.disposables);
+        this.onKeyDown.filter(e => e.keyCode === 16 /* UpArrow */).on(this.onUpArrow, this, this.disposables);
+        this.onKeyDown.filter(e => e.keyCode === 18 /* DownArrow */).on(this.onDownArrow, this, this.disposables);
+        this.onKeyDown.filter(e => e.keyCode === 11 /* PageUp */).on(this.onPageUpArrow, this, this.disposables);
+        this.onKeyDown.filter(e => e.keyCode === 12 /* PageDown */).on(this.onPageDownArrow, this, this.disposables);
+        this.onKeyDown.filter(e => e.keyCode === 9 /* Escape */).on(this.onEscape, this, this.disposables);
+        if (options.multipleSelectionSupport) {
+            this.onKeyDown.filter(e => (platform.isMacintosh ? e.metaKey : e.ctrlKey) && e.keyCode === 31 /* KEY_A */).on(this.onCtrlA, this, this.multipleSelectionDisposables);
+        }
+    }
+    get onKeyDown() {
+        return Event.chain(this.disposables.add(new DomEmitter(this.view.domNode, 'keydown')).event)
             .filter(e => !isInputElement(e.target))
             .map(e => new StandardKeyboardEvent(e));
-        onKeyDown.filter(e => e.keyCode === 3 /* Enter */).on(this.onEnter, this, this.disposables);
-        onKeyDown.filter(e => e.keyCode === 16 /* UpArrow */).on(this.onUpArrow, this, this.disposables);
-        onKeyDown.filter(e => e.keyCode === 18 /* DownArrow */).on(this.onDownArrow, this, this.disposables);
-        onKeyDown.filter(e => e.keyCode === 11 /* PageUp */).on(this.onPageUpArrow, this, this.disposables);
-        onKeyDown.filter(e => e.keyCode === 12 /* PageDown */).on(this.onPageDownArrow, this, this.disposables);
-        onKeyDown.filter(e => e.keyCode === 9 /* Escape */).on(this.onEscape, this, this.disposables);
-        if (multipleSelectionSupport) {
-            onKeyDown.filter(e => (platform.isMacintosh ? e.metaKey : e.ctrlKey) && e.keyCode === 31 /* KEY_A */).on(this.onCtrlA, this, this.disposables);
+    }
+    updateOptions(optionsUpdate) {
+        if (optionsUpdate.multipleSelectionSupport !== undefined) {
+            this.multipleSelectionDisposables.clear();
+            if (optionsUpdate.multipleSelectionSupport) {
+                this.onKeyDown.filter(e => (platform.isMacintosh ? e.metaKey : e.ctrlKey) && e.keyCode === 31 /* KEY_A */).on(this.onCtrlA, this, this.multipleSelectionDisposables);
+            }
         }
     }
     onEnter(e) {
@@ -272,8 +291,12 @@ class KeyboardController {
     }
     dispose() {
         this.disposables.dispose();
+        this.multipleSelectionDisposables.dispose();
     }
 }
+__decorate([
+    memoize
+], KeyboardController.prototype, "onKeyDown", null);
 var TypeLabelControllerState;
 (function (TypeLabelControllerState) {
     TypeLabelControllerState[TypeLabelControllerState["Idle"] = 0] = "Idle";
@@ -321,7 +344,7 @@ class TypeLabelController {
         if (this.enabled) {
             return;
         }
-        const onChar = Event.chain(domEvent(this.view.domNode, 'keydown'))
+        const onChar = Event.chain(this.enabledDisposables.add(new DomEmitter(this.view.domNode, 'keydown')).event)
             .filter(e => !isInputElement(e.target))
             .filter(() => this.automaticKeyboardNavigation || this.triggered)
             .map(event => new StandardKeyboardEvent(event))
@@ -390,7 +413,7 @@ class DOMFocusController {
         this.list = list;
         this.view = view;
         this.disposables = new DisposableStore();
-        const onKeyDown = Event.chain(domEvent(view.domNode, 'keydown'))
+        const onKeyDown = Event.chain(this.disposables.add(new DomEmitter(view.domNode, 'keydown')).event)
             .filter(e => !isInputElement(e.target))
             .map(e => new StandardKeyboardEvent(e));
         onKeyDown.filter(e => e.keyCode === 2 /* Tab */ && !e.ctrlKey && !e.metaKey && !e.shiftKey && !e.altKey)
@@ -443,9 +466,8 @@ export class MouseController {
         this.disposables = new DisposableStore();
         this._onPointer = new Emitter();
         this.onPointer = this._onPointer.event;
-        this.multipleSelectionSupport = !(list.options.multipleSelectionSupport === false);
-        if (this.multipleSelectionSupport) {
-            this.multipleSelectionController = list.options.multipleSelectionController || DefaultMultipleSelectionController;
+        if (list.options.multipleSelectionSupport !== false) {
+            this.multipleSelectionController = this.list.options.multipleSelectionController || DefaultMultipleSelectionController;
         }
         this.mouseSupport = typeof list.options.mouseSupport === 'undefined' || !!list.options.mouseSupport;
         if (this.mouseSupport) {
@@ -457,17 +479,25 @@ export class MouseController {
         }
         Event.any(list.onMouseClick, list.onMouseMiddleClick, list.onTap)(this.onViewPointer, this, this.disposables);
     }
-    isSelectionSingleChangeEvent(event) {
-        if (this.multipleSelectionController) {
-            return this.multipleSelectionController.isSelectionSingleChangeEvent(event);
+    updateOptions(optionsUpdate) {
+        if (optionsUpdate.multipleSelectionSupport !== undefined) {
+            this.multipleSelectionController = undefined;
+            if (optionsUpdate.multipleSelectionSupport) {
+                this.multipleSelectionController = this.list.options.multipleSelectionController || DefaultMultipleSelectionController;
+            }
         }
-        return platform.isMacintosh ? event.browserEvent.metaKey : event.browserEvent.ctrlKey;
+    }
+    isSelectionSingleChangeEvent(event) {
+        if (!this.multipleSelectionController) {
+            return false;
+        }
+        return this.multipleSelectionController.isSelectionSingleChangeEvent(event);
     }
     isSelectionRangeChangeEvent(event) {
-        if (this.multipleSelectionController) {
-            return this.multipleSelectionController.isSelectionRangeChangeEvent(event);
+        if (!this.multipleSelectionController) {
+            return false;
         }
-        return event.browserEvent.shiftKey;
+        return this.multipleSelectionController.isSelectionRangeChangeEvent(event);
     }
     isSelectionChangeEvent(event) {
         return this.isSelectionSingleChangeEvent(event) || this.isSelectionRangeChangeEvent(event);
@@ -501,10 +531,10 @@ export class MouseController {
             this.list.setAnchor(undefined);
             return;
         }
-        if (this.multipleSelectionSupport && this.isSelectionRangeChangeEvent(e)) {
+        if (this.isSelectionRangeChangeEvent(e)) {
             return this.changeSelection(e);
         }
-        if (this.multipleSelectionSupport && this.isSelectionChangeEvent(e)) {
+        if (this.isSelectionChangeEvent(e)) {
             return this.changeSelection(e);
         }
         this.list.setFocus([focus], e.browserEvent);
@@ -518,7 +548,7 @@ export class MouseController {
         if (isInputElement(e.browserEvent.target) || isMonacoEditor(e.browserEvent.target)) {
             return;
         }
-        if (this.multipleSelectionSupport && this.isSelectionChangeEvent(e)) {
+        if (this.isSelectionChangeEvent(e)) {
             return;
         }
         const focus = this.list.getFocus();
@@ -592,6 +622,9 @@ export class DefaultStyleController {
         if (styles.listActiveSelectionForeground) {
             content.push(`.monaco-list${suffix}:focus .monaco-list-row.selected { color: ${styles.listActiveSelectionForeground}; }`);
         }
+        if (styles.listActiveSelectionIconForeground) {
+            content.push(`.monaco-list${suffix}:focus .monaco-list-row.selected .codicon { color: ${styles.listActiveSelectionIconForeground}; }`);
+        }
         if (styles.listFocusAndSelectionBackground) {
             content.push(`
 				.monaco-drag-image,
@@ -608,6 +641,9 @@ export class DefaultStyleController {
             content.push(`.monaco-list${suffix} .monaco-list-row.focused { color:  ${styles.listInactiveFocusForeground}; }`);
             content.push(`.monaco-list${suffix} .monaco-list-row.focused:hover { color:  ${styles.listInactiveFocusForeground}; }`); // overwrite :hover style in this case!
         }
+        if (styles.listInactiveSelectionIconForeground) {
+            content.push(`.monaco-list${suffix} .monaco-list-row.focused .codicon { color:  ${styles.listInactiveSelectionIconForeground}; }`);
+        }
         if (styles.listInactiveFocusBackground) {
             content.push(`.monaco-list${suffix} .monaco-list-row.focused { background-color:  ${styles.listInactiveFocusBackground}; }`);
             content.push(`.monaco-list${suffix} .monaco-list-row.focused:hover { background-color:  ${styles.listInactiveFocusBackground}; }`); // overwrite :hover style in this case!
@@ -673,9 +709,11 @@ const defaultStyles = {
     listFocusBackground: Color.fromHex('#7FB0D0'),
     listActiveSelectionBackground: Color.fromHex('#0E639C'),
     listActiveSelectionForeground: Color.fromHex('#FFFFFF'),
+    listActiveSelectionIconForeground: Color.fromHex('#FFFFFF'),
     listFocusAndSelectionBackground: Color.fromHex('#094771'),
     listFocusAndSelectionForeground: Color.fromHex('#FFFFFF'),
     listInactiveSelectionBackground: Color.fromHex('#3F3F46'),
+    listInactiveSelectionIconForeground: Color.fromHex('#FFFFFF'),
     listHoverBackground: Color.fromHex('#2A2D2E'),
     listDropBackground: Color.fromHex('#383B3D'),
     treeIndentGuidesStroke: Color.fromHex('#a9a9a9'),
@@ -856,6 +894,10 @@ class ListViewDragAndDrop {
     onDragOver(data, targetElement, targetIndex, originalEvent) {
         return this.dnd.onDragOver(data, targetElement, targetIndex, originalEvent);
     }
+    onDragLeave(data, targetElement, targetIndex, originalEvent) {
+        var _a, _b;
+        (_b = (_a = this.dnd).onDragLeave) === null || _b === void 0 ? void 0 : _b.call(_a, data, targetElement, targetIndex, originalEvent);
+    }
     onDragEnd(originalEvent) {
         if (this.dnd.onDragEnd) {
             this.dnd.onDragEnd(originalEvent);
@@ -910,12 +952,10 @@ export class List {
         this.disposables.add(this.anchor);
         this.disposables.add(this.view);
         this.disposables.add(this._onDidDispose);
-        this.onDidFocus = Event.map(domEvent(this.view.domNode, 'focus', true), () => null);
-        this.onDidBlur = Event.map(domEvent(this.view.domNode, 'blur', true), () => null);
         this.disposables.add(new DOMFocusController(this, this.view));
         if (typeof _options.keyboardSupport !== 'boolean' || _options.keyboardSupport) {
-            const controller = new KeyboardController(this, this.view, _options);
-            this.disposables.add(controller);
+            this.keyboardController = new KeyboardController(this, this.view, _options);
+            this.disposables.add(this.keyboardController);
         }
         if (_options.keyboardNavigationLabelProvider) {
             const delegate = _options.keyboardNavigationDelegate || DefaultKeyboardNavigationDelegate;
@@ -929,7 +969,7 @@ export class List {
         if (this.accessibilityProvider) {
             this.ariaLabel = this.accessibilityProvider.getWidgetAriaLabel();
         }
-        if (_options.multipleSelectionSupport) {
+        if (this._options.multipleSelectionSupport) {
             this.view.domNode.setAttribute('aria-multiselectable', 'true');
         }
     }
@@ -956,13 +996,13 @@ export class List {
      */
     get onContextMenu() {
         let didJustPressContextMenuKey = false;
-        const fromKeyDown = Event.chain(domEvent(this.view.domNode, 'keydown'))
+        const fromKeyDown = Event.chain(this.disposables.add(new DomEmitter(this.view.domNode, 'keydown')).event)
             .map(e => new StandardKeyboardEvent(e))
             .filter(e => didJustPressContextMenuKey = e.keyCode === 58 /* ContextMenu */ || (e.shiftKey && e.keyCode === 68 /* F10 */))
             .map(stopEvent)
             .filter(() => false)
             .event;
-        const fromKeyUp = Event.chain(domEvent(this.view.domNode, 'keyup'))
+        const fromKeyUp = Event.chain(this.disposables.add(new DomEmitter(this.view.domNode, 'keyup')).event)
             .forEach(() => didJustPressContextMenuKey = false)
             .map(e => new StandardKeyboardEvent(e))
             .filter(e => e.keyCode === 58 /* ContextMenu */ || (e.shiftKey && e.keyCode === 68 /* F10 */))
@@ -981,15 +1021,27 @@ export class List {
             .event;
         return Event.any(fromKeyDown, fromKeyUp, fromMouse);
     }
-    get onKeyDown() { return domEvent(this.view.domNode, 'keydown'); }
+    get onKeyDown() { return this.disposables.add(new DomEmitter(this.view.domNode, 'keydown')).event; }
+    get onDidFocus() { return Event.signal(this.disposables.add(new DomEmitter(this.view.domNode, 'focus', true)).event); }
     createMouseController(options) {
         return new MouseController(this);
     }
     updateOptions(optionsUpdate = {}) {
+        var _a;
         this._options = Object.assign(Object.assign({}, this._options), optionsUpdate);
         if (this.typeLabelController) {
             this.typeLabelController.updateOptions(this._options);
         }
+        if (this._options.multipleSelectionController !== undefined) {
+            if (this._options.multipleSelectionSupport) {
+                this.view.domNode.setAttribute('aria-multiselectable', 'true');
+            }
+            else {
+                this.view.domNode.removeAttribute('aria-multiselectable');
+            }
+        }
+        this.mouseController.updateOptions(optionsUpdate);
+        (_a = this.keyboardController) === null || _a === void 0 ? void 0 : _a.updateOptions(optionsUpdate);
         this.view.updateOptions(optionsUpdate);
     }
     get options() {
@@ -1065,6 +1117,10 @@ export class List {
     getAnchor() {
         return firstOrDefault(this.anchor.get(), undefined);
     }
+    getAnchorElement() {
+        const anchor = this.getAnchor();
+        return typeof anchor === 'undefined' ? undefined : this.element(anchor);
+    }
     setFocus(indexes, browserEvent) {
         for (const index of indexes) {
             if (index < 0 || index >= this.length) {
@@ -1299,3 +1355,9 @@ __decorate([
 __decorate([
     memoize
 ], List.prototype, "onContextMenu", null);
+__decorate([
+    memoize
+], List.prototype, "onKeyDown", null);
+__decorate([
+    memoize
+], List.prototype, "onDidFocus", null);
