@@ -18,6 +18,7 @@ export class BareFontInfo {
      * @internal
      */
     constructor(opts) {
+        this._bareFontInfoBrand = undefined;
         this.zoomLevel = opts.zoomLevel;
         this.pixelRatio = opts.pixelRatio;
         this.fontFamily = String(opts.fontFamily);
@@ -44,9 +45,15 @@ export class BareFontInfo {
      */
     static _create(fontFamily, fontWeight, fontSize, fontFeatureSettings, lineHeight, letterSpacing, zoomLevel, pixelRatio, ignoreEditorZoom) {
         if (lineHeight === 0) {
-            lineHeight = Math.round(GOLDEN_LINE_HEIGHT_RATIO * fontSize);
+            lineHeight = GOLDEN_LINE_HEIGHT_RATIO * fontSize;
         }
         else if (lineHeight < MINIMUM_LINE_HEIGHT) {
+            // Values too small to be line heights in pixels are probably in ems. Accept them gracefully.
+            lineHeight = lineHeight * fontSize;
+        }
+        // Enforce integer, minimum constraints
+        lineHeight = Math.round(lineHeight);
+        if (lineHeight < MINIMUM_LINE_HEIGHT) {
             lineHeight = MINIMUM_LINE_HEIGHT;
         }
         const editorZoomLevelMultiplier = 1 + (ignoreEditorZoom ? 0 : EditorZoom.getZoomLevel() * 0.1);
@@ -92,6 +99,7 @@ export class FontInfo extends BareFontInfo {
      */
     constructor(opts, isTrusted) {
         super(opts);
+        this._editorStylingBrand = undefined;
         this.version = SERIALIZED_FONT_INFO_VERSION;
         this.isTrusted = isTrusted;
         this.isMonospace = opts.isMonospace;
