@@ -26,17 +26,17 @@ import * as strings from '../../../base/common/strings.js';
 import { Range } from '../../common/core/range.js';
 import { CONTEXT_FIND_INPUT_FOCUSED, CONTEXT_REPLACE_INPUT_FOCUSED, FIND_IDS, MATCHES_LIMIT } from './findModel.js';
 import { contrastBorder, editorFindMatch, editorFindMatchBorder, editorFindMatchHighlight, editorFindMatchHighlightBorder, editorFindRangeHighlight, editorFindRangeHighlightBorder, editorWidgetBackground, editorWidgetBorder, editorWidgetResizeBorder, errorForeground, inputActiveOptionBorder, inputActiveOptionBackground, inputActiveOptionForeground, inputBackground, inputBorder, inputForeground, inputValidationErrorBackground, inputValidationErrorBorder, inputValidationErrorForeground, inputValidationInfoBackground, inputValidationInfoBorder, inputValidationInfoForeground, inputValidationWarningBackground, inputValidationWarningBorder, inputValidationWarningForeground, widgetShadow, editorWidgetForeground, focusBorder } from '../../../platform/theme/common/colorRegistry.js';
-import { registerThemingParticipant } from '../../../platform/theme/common/themeService.js';
+import { registerThemingParticipant, ThemeIcon } from '../../../platform/theme/common/themeService.js';
 import { ContextScopedFindInput, ContextScopedReplaceInput } from '../../../platform/browser/contextScopedHistoryWidget.js';
-import { Codicon, registerIcon } from '../../../base/common/codicons.js';
-const findSelectionIcon = registerIcon('find-selection', Codicon.selection);
-const findCollapsedIcon = registerIcon('find-collapsed', Codicon.chevronRight);
-const findExpandedIcon = registerIcon('find-expanded', Codicon.chevronDown);
-export const findCloseIcon = registerIcon('find-close', Codicon.close);
-export const findReplaceIcon = registerIcon('find-replace', Codicon.replace);
-export const findReplaceAllIcon = registerIcon('find-replace-all', Codicon.replaceAll);
-export const findPreviousMatchIcon = registerIcon('find-previous-match', Codicon.arrowUp);
-export const findNextMatchIcon = registerIcon('find-next-match', Codicon.arrowDown);
+import { Codicon } from '../../../base/common/codicons.js';
+import { registerIcon, widgetClose } from '../../../platform/theme/common/iconRegistry.js';
+const findSelectionIcon = registerIcon('find-selection', Codicon.selection, nls.localize('findSelectionIcon', 'Icon for \'Find in Selection\' in the editor find widget.'));
+const findCollapsedIcon = registerIcon('find-collapsed', Codicon.chevronRight, nls.localize('findCollapsedIcon', 'Icon to indicate that the editor find widget is collapsed.'));
+const findExpandedIcon = registerIcon('find-expanded', Codicon.chevronDown, nls.localize('findExpandedIcon', 'Icon to indicate that the editor find widget is expanded.'));
+export const findReplaceIcon = registerIcon('find-replace', Codicon.replace, nls.localize('findReplaceIcon', 'Icon for \'Replace\' in the editor find widget.'));
+export const findReplaceAllIcon = registerIcon('find-replace-all', Codicon.replaceAll, nls.localize('findReplaceAllIcon', 'Icon for \'Replace All\' in the editor find widget.'));
+export const findPreviousMatchIcon = registerIcon('find-previous-match', Codicon.arrowUp, nls.localize('findPreviousMatchIcon', 'Icon for \'Find Previous\' in the editor find widget.'));
+export const findNextMatchIcon = registerIcon('find-next-match', Codicon.arrowDown, nls.localize('findNextMatchIcon', 'Icon for \'Find Next\' in the editor find widget.'));
 const NLS_FIND_INPUT_LABEL = nls.localize('label.find', "Find");
 const NLS_FIND_INPUT_PLACEHOLDER = nls.localize('placeholder.find', "Find");
 const NLS_PREVIOUS_MATCH_BTN_LABEL = nls.localize('label.previousMatchButton', "Previous match");
@@ -49,8 +49,8 @@ const NLS_REPLACE_BTN_LABEL = nls.localize('label.replaceButton', "Replace");
 const NLS_REPLACE_ALL_BTN_LABEL = nls.localize('label.replaceAllButton', "Replace All");
 const NLS_TOGGLE_REPLACE_MODE_BTN_LABEL = nls.localize('label.toggleReplaceButton', "Toggle Replace mode");
 const NLS_MATCHES_COUNT_LIMIT_TITLE = nls.localize('title.matchesCountLimit', "Only the first {0} results are highlighted, but all find operations work on the entire text.", MATCHES_LIMIT);
-const NLS_MATCHES_LOCATION = nls.localize('label.matchesLocation', "{0} of {1}");
-const NLS_NO_RESULTS = nls.localize('label.noResults', "No results");
+export const NLS_MATCHES_LOCATION = nls.localize('label.matchesLocation', "{0} of {1}");
+export const NLS_NO_RESULTS = nls.localize('label.noResults', "No results");
 const FIND_WIDGET_INITIAL_WIDTH = 419;
 const PART_WIDTH = 275;
 const FIND_INPUT_AREA_WIDTH = PART_WIDTH - 54;
@@ -83,9 +83,10 @@ function stopPropagationForMultiLineDownwards(event, value, textarea) {
     }
 }
 export class FindWidget extends Widget {
-    constructor(codeEditor, controller, state, contextViewProvider, keybindingService, contextKeyService, themeService, storageService, notificationService, storageKeysSyncRegistryService) {
+    constructor(codeEditor, controller, state, contextViewProvider, keybindingService, contextKeyService, themeService, storageService, notificationService) {
         super();
         this._cachedHeight = null;
+        this._revealTimeouts = [];
         this._codeEditor = codeEditor;
         this._controller = controller;
         this._state = state;
@@ -94,7 +95,6 @@ export class FindWidget extends Widget {
         this._contextKeyService = contextKeyService;
         this._storageService = storageService;
         this._notificationService = notificationService;
-        storageKeysSyncRegistryService.registerStorageKey({ key: ctrlEnterReplaceAllWarningPromptedKey, version: 1 });
         this._ctrlEnterReplaceAllWarningPrompted = !!storageService.getBoolean(ctrlEnterReplaceAllWarningPromptedKey, 0 /* GLOBAL */);
         this._isVisible = false;
         this._isReplaceVisible = false;
@@ -107,21 +107,21 @@ export class FindWidget extends Widget {
         this._tryUpdateWidgetWidth();
         this._findInput.inputBox.layout();
         this._register(this._codeEditor.onDidChangeConfiguration((e) => {
-            if (e.hasChanged(72 /* readOnly */)) {
-                if (this._codeEditor.getOption(72 /* readOnly */)) {
+            if (e.hasChanged(78 /* readOnly */)) {
+                if (this._codeEditor.getOption(78 /* readOnly */)) {
                     // Hide replace part if editor becomes read only
                     this._state.change({ isReplaceRevealed: false }, false);
                 }
                 this._updateButtons();
             }
-            if (e.hasChanged(117 /* layoutInfo */)) {
+            if (e.hasChanged(128 /* layoutInfo */)) {
                 this._tryUpdateWidgetWidth();
             }
             if (e.hasChanged(2 /* accessibilitySupport */)) {
                 this.updateAccessibilitySupport();
             }
-            if (e.hasChanged(29 /* find */)) {
-                const addExtraSpaceOnTop = this._codeEditor.getOption(29 /* find */).addExtraSpaceOnTop;
+            if (e.hasChanged(33 /* find */)) {
+                const addExtraSpaceOnTop = this._codeEditor.getOption(33 /* find */).addExtraSpaceOnTop;
                 if (addExtraSpaceOnTop && !this._viewZone) {
                     this._viewZone = new FindWidgetViewZone(0);
                     this._showViewZone();
@@ -141,7 +141,7 @@ export class FindWidget extends Widget {
             if (this._isVisible) {
                 let globalBufferTerm = yield this._controller.getGlobalBufferTerm();
                 if (globalBufferTerm && globalBufferTerm !== this._state.searchString) {
-                    this._state.change({ searchString: globalBufferTerm }, true);
+                    this._state.change({ searchString: globalBufferTerm }, false);
                     this._findInput.select();
                 }
             }
@@ -165,7 +165,7 @@ export class FindWidget extends Widget {
             this._replaceInputFocused.set(false);
         }));
         this._codeEditor.addOverlayWidget(this);
-        if (this._codeEditor.getOption(29 /* find */).addExtraSpaceOnTop) {
+        if (this._codeEditor.getOption(33 /* find */).addExtraSpaceOnTop) {
             this._viewZone = new FindWidgetViewZone(0); // Put it before the first line then users can scroll beyond the first line.
         }
         this._applyTheme(themeService.getColorTheme());
@@ -227,7 +227,7 @@ export class FindWidget extends Widget {
         }
         if (e.isReplaceRevealed) {
             if (this._state.isReplaceRevealed) {
-                if (!this._codeEditor.getOption(72 /* readOnly */) && !this._isReplaceVisible) {
+                if (!this._codeEditor.getOption(78 /* readOnly */) && !this._isReplaceVisible) {
                     this._isReplaceVisible = true;
                     this._replaceInput.width = dom.getTotalWidth(this._findInput.domNode);
                     this._updateButtons();
@@ -255,6 +255,9 @@ export class FindWidget extends Widget {
         if (e.matchCase) {
             this._findInput.setCaseSensitive(this._state.matchCase);
         }
+        if (e.preserveCase) {
+            this._replaceInput.setPreserveCase(this._state.preserveCase);
+        }
         if (e.searchScope) {
             if (this._state.searchScope) {
                 this._toggleSelectionFind.checked = true;
@@ -266,7 +269,7 @@ export class FindWidget extends Widget {
         }
         if (e.searchString || e.matchesCount || e.matchesPosition) {
             let showRedOutline = (this._state.searchString.length > 0 && this._state.matchesCount === 0);
-            dom.toggleClass(this._domNode, 'no-results', showRedOutline);
+            this._domNode.classList.toggle('no-results', showRedOutline);
             this._updateMatchesCount();
             this._updateButtons();
         }
@@ -281,7 +284,7 @@ export class FindWidget extends Widget {
         }
     }
     _delayedUpdateHistory() {
-        this._updateHistoryDelayer.trigger(this._updateHistory.bind(this));
+        this._updateHistoryDelayer.trigger(this._updateHistory.bind(this)).then(undefined, onUnexpectedError);
     }
     _updateHistory() {
         if (this._state.searchString) {
@@ -366,16 +369,20 @@ export class FindWidget extends Widget {
         this._nextBtn.setEnabled(this._isVisible && findInputIsNonEmpty && matchesCount && this._state.canNavigateForward());
         this._replaceBtn.setEnabled(this._isVisible && this._isReplaceVisible && findInputIsNonEmpty);
         this._replaceAllBtn.setEnabled(this._isVisible && this._isReplaceVisible && findInputIsNonEmpty);
-        dom.toggleClass(this._domNode, 'replaceToggled', this._isReplaceVisible);
+        this._domNode.classList.toggle('replaceToggled', this._isReplaceVisible);
         this._toggleReplaceBtn.setExpanded(this._isReplaceVisible);
-        let canReplace = !this._codeEditor.getOption(72 /* readOnly */);
+        let canReplace = !this._codeEditor.getOption(78 /* readOnly */);
         this._toggleReplaceBtn.setEnabled(this._isVisible && canReplace);
     }
     _reveal() {
+        this._revealTimeouts.forEach(e => {
+            clearTimeout(e);
+        });
+        this._revealTimeouts = [];
         if (!this._isVisible) {
             this._isVisible = true;
             const selection = this._codeEditor.getSelection();
-            switch (this._codeEditor.getOption(29 /* find */).autoFindInSelection) {
+            switch (this._codeEditor.getOption(33 /* find */).autoFindInSelection) {
                 case 'always':
                     this._toggleSelectionFind.checked = true;
                     break;
@@ -391,17 +398,17 @@ export class FindWidget extends Widget {
             }
             this._tryUpdateWidgetWidth();
             this._updateButtons();
-            setTimeout(() => {
-                dom.addClass(this._domNode, 'visible');
+            this._revealTimeouts.push(setTimeout(() => {
+                this._domNode.classList.add('visible');
                 this._domNode.setAttribute('aria-hidden', 'false');
-            }, 0);
+            }, 0));
             // validate query again as it's being dismissed when we hide the find widget.
-            setTimeout(() => {
+            this._revealTimeouts.push(setTimeout(() => {
                 this._findInput.validate();
-            }, 200);
+            }, 200));
             this._codeEditor.layoutOverlayWidget(this);
             let adjustEditorScrollTop = true;
-            if (this._codeEditor.getOption(29 /* find */).seedSearchStringFromSelection && selection) {
+            if (this._codeEditor.getOption(33 /* find */).seedSearchStringFromSelection && selection) {
                 const domNode = this._codeEditor.getDomNode();
                 if (domNode) {
                     const editorCoords = dom.getDomNodePagePosition(domNode);
@@ -428,10 +435,14 @@ export class FindWidget extends Widget {
         }
     }
     _hide(focusTheEditor) {
+        this._revealTimeouts.forEach(e => {
+            clearTimeout(e);
+        });
+        this._revealTimeouts = [];
         if (this._isVisible) {
             this._isVisible = false;
             this._updateButtons();
-            dom.removeClass(this._domNode, 'visible');
+            this._domNode.classList.remove('visible');
             this._domNode.setAttribute('aria-hidden', 'true');
             this._findInput.clearMessage();
             if (focusTheEditor) {
@@ -441,8 +452,8 @@ export class FindWidget extends Widget {
             this._removeViewZone();
         }
     }
-    _layoutViewZone() {
-        const addExtraSpaceOnTop = this._codeEditor.getOption(29 /* find */).addExtraSpaceOnTop;
+    _layoutViewZone(targetScrollTop) {
+        const addExtraSpaceOnTop = this._codeEditor.getOption(33 /* find */).addExtraSpaceOnTop;
         if (!addExtraSpaceOnTop) {
             this._removeViewZone();
             return;
@@ -458,14 +469,14 @@ export class FindWidget extends Widget {
             viewZone.heightInPx = this._getHeight();
             this._viewZoneId = accessor.addZone(viewZone);
             // scroll top adjust to make sure the editor doesn't scroll when adding viewzone at the beginning.
-            this._codeEditor.setScrollTop(this._codeEditor.getScrollTop() + viewZone.heightInPx);
+            this._codeEditor.setScrollTop(targetScrollTop || this._codeEditor.getScrollTop() + viewZone.heightInPx);
         });
     }
     _showViewZone(adjustScroll = true) {
         if (!this._isVisible) {
             return;
         }
-        const addExtraSpaceOnTop = this._codeEditor.getOption(29 /* find */).addExtraSpaceOnTop;
+        const addExtraSpaceOnTop = this._codeEditor.getOption(33 /* find */).addExtraSpaceOnTop;
         if (!addExtraSpaceOnTop) {
             return;
         }
@@ -491,7 +502,7 @@ export class FindWidget extends Widget {
             else {
                 let scrollAdjustment = this._getHeight();
                 // if the editor has top padding, factor that into the zone height
-                scrollAdjustment -= this._codeEditor.getOption(66 /* padding */).top;
+                scrollAdjustment -= this._codeEditor.getOption(72 /* padding */).top;
                 if (scrollAdjustment <= 0) {
                     return;
                 }
@@ -549,11 +560,11 @@ export class FindWidget extends Widget {
         const editorContentWidth = layoutInfo.contentWidth;
         if (editorContentWidth <= 0) {
             // for example, diff view original editor
-            dom.addClass(this._domNode, 'hiddenEditor');
+            this._domNode.classList.add('hiddenEditor');
             return;
         }
-        else if (dom.hasClass(this._domNode, 'hiddenEditor')) {
-            dom.removeClass(this._domNode, 'hiddenEditor');
+        else if (this._domNode.classList.contains('hiddenEditor')) {
+            this._domNode.classList.remove('hiddenEditor');
         }
         const editorWidth = layoutInfo.width;
         const minimapWidth = layoutInfo.minimap.minimapWidth;
@@ -578,9 +589,9 @@ export class FindWidget extends Widget {
         if (FIND_WIDGET_INITIAL_WIDTH + 28 + minimapWidth - MAX_MATCHES_COUNT_WIDTH >= editorWidth + 50) {
             collapsedFindWidget = true;
         }
-        dom.toggleClass(this._domNode, 'collapsed-find-widget', collapsedFindWidget);
-        dom.toggleClass(this._domNode, 'narrow-find-widget', narrowFindWidget);
-        dom.toggleClass(this._domNode, 'reduced-find-widget', reducedFindWidget);
+        this._domNode.classList.toggle('collapsed-find-widget', collapsedFindWidget);
+        this._domNode.classList.toggle('narrow-find-widget', narrowFindWidget);
+        this._domNode.classList.toggle('reduced-find-widget', reducedFindWidget);
         if (!narrowFindWidget && !collapsedFindWidget) {
             // the minimal left offset of findwidget is 15px.
             this._domNode.style.maxWidth = `${editorWidth - 28 - minimapWidth - 15}px`;
@@ -697,7 +708,7 @@ export class FindWidget extends Widget {
                 // this is the first time when users press Ctrl + Enter to replace all
                 this._notificationService.info(nls.localize('ctrlEnter.keybindingChanged', 'Ctrl+Enter now inserts line break instead of replacing all. You can modify the keybinding for editor.action.replaceAll to override this behavior.'));
                 this._ctrlEnterReplaceAllWarningPrompted = true;
-                this._storageService.store(ctrlEnterReplaceAllWarningPromptedKey, true, 0 /* GLOBAL */);
+                this._storageService.store(ctrlEnterReplaceAllWarningPromptedKey, true, 0 /* GLOBAL */, 0 /* USER */);
             }
             this._replaceInput.inputBox.insertAtCursor('\n');
             e.preventDefault();
@@ -812,7 +823,7 @@ export class FindWidget extends Widget {
         // Previous button
         this._prevBtn = this._register(new SimpleButton({
             label: NLS_PREVIOUS_MATCH_BTN_LABEL + this._keybindingLabelFor(FIND_IDS.PreviousMatchFindAction),
-            className: findPreviousMatchIcon.classNames,
+            icon: findPreviousMatchIcon,
             onTrigger: () => {
                 this._codeEditor.getAction(FIND_IDS.PreviousMatchFindAction).run().then(undefined, onUnexpectedError);
             }
@@ -820,7 +831,7 @@ export class FindWidget extends Widget {
         // Next button
         this._nextBtn = this._register(new SimpleButton({
             label: NLS_NEXT_MATCH_BTN_LABEL + this._keybindingLabelFor(FIND_IDS.NextMatchFindAction),
-            className: findNextMatchIcon.classNames,
+            icon: findNextMatchIcon,
             onTrigger: () => {
                 this._codeEditor.getAction(FIND_IDS.NextMatchFindAction).run().then(undefined, onUnexpectedError);
             }
@@ -866,7 +877,7 @@ export class FindWidget extends Widget {
         // Close button
         this._closeBtn = this._register(new SimpleButton({
             label: NLS_CLOSE_BTN_LABEL + this._keybindingLabelFor(FIND_IDS.CloseFindWidgetCommand),
-            className: findCloseIcon.classNames,
+            icon: widgetClose,
             onTrigger: () => {
                 this._state.change({ isRevealed: false, searchScope: null }, false);
             },
@@ -889,6 +900,7 @@ export class FindWidget extends Widget {
         this._replaceInput = this._register(new ContextScopedReplaceInput(null, undefined, {
             label: NLS_REPLACE_INPUT_LABEL,
             placeholder: NLS_REPLACE_INPUT_PLACEHOLDER,
+            appendPreserveCaseLabel: this._keybindingLabelFor(FIND_IDS.TogglePreserveCaseCommand),
             history: [],
             flexibleHeight,
             flexibleWidth,
@@ -929,7 +941,7 @@ export class FindWidget extends Widget {
         // Replace one button
         this._replaceBtn = this._register(new SimpleButton({
             label: NLS_REPLACE_BTN_LABEL + this._keybindingLabelFor(FIND_IDS.ReplaceOneAction),
-            className: findReplaceIcon.classNames,
+            icon: findReplaceIcon,
             onTrigger: () => {
                 this._controller.replace();
             },
@@ -943,7 +955,7 @@ export class FindWidget extends Widget {
         // Replace all button
         this._replaceAllBtn = this._register(new SimpleButton({
             label: NLS_REPLACE_ALL_BTN_LABEL + this._keybindingLabelFor(FIND_IDS.ReplaceAllAction),
-            className: findReplaceAllIcon.classNames,
+            icon: findReplaceAllIcon,
             onTrigger: () => {
                 this._controller.replaceAll();
             }
@@ -1040,10 +1052,17 @@ export class SimpleButton extends Widget {
     constructor(opts) {
         super();
         this._opts = opts;
+        let className = 'button';
+        if (this._opts.className) {
+            className = className + ' ' + this._opts.className;
+        }
+        if (this._opts.icon) {
+            className = className + ' ' + ThemeIcon.asClassName(this._opts.icon);
+        }
         this._domNode = document.createElement('div');
         this._domNode.title = this._opts.label;
         this._domNode.tabIndex = 0;
-        this._domNode.className = 'button ' + this._opts.className;
+        this._domNode.className = className;
         this._domNode.setAttribute('role', 'button');
         this._domNode.setAttribute('aria-label', this._opts.label);
         this.onclick(this._domNode, (e) => {
@@ -1071,19 +1090,19 @@ export class SimpleButton extends Widget {
         this._domNode.focus();
     }
     setEnabled(enabled) {
-        dom.toggleClass(this._domNode, 'disabled', !enabled);
+        this._domNode.classList.toggle('disabled', !enabled);
         this._domNode.setAttribute('aria-disabled', String(!enabled));
         this._domNode.tabIndex = enabled ? 0 : -1;
     }
     setExpanded(expanded) {
         this._domNode.setAttribute('aria-expanded', String(!!expanded));
         if (expanded) {
-            dom.removeClasses(this._domNode, findCollapsedIcon.classNames);
-            dom.addClasses(this._domNode, findExpandedIcon.classNames);
+            this._domNode.classList.remove(...ThemeIcon.asClassNameArray(findCollapsedIcon));
+            this._domNode.classList.add(...ThemeIcon.asClassNameArray(findExpandedIcon));
         }
         else {
-            dom.removeClasses(this._domNode, findExpandedIcon.classNames);
-            dom.addClasses(this._domNode, findCollapsedIcon.classNames);
+            this._domNode.classList.remove(...ThemeIcon.asClassNameArray(findExpandedIcon));
+            this._domNode.classList.add(...ThemeIcon.asClassNameArray(findCollapsedIcon));
         }
     }
 }
@@ -1101,7 +1120,7 @@ registerThemingParticipant((theme, collector) => {
     addBackgroundColorRule('.find-widget', widgetBackground);
     const widgetShadowColor = theme.getColor(widgetShadow);
     if (widgetShadowColor) {
-        collector.addRule(`.monaco-editor .find-widget { box-shadow: 0 2px 8px ${widgetShadowColor}; }`);
+        collector.addRule(`.monaco-editor .find-widget { box-shadow: 0 0 8px 2px ${widgetShadowColor}; }`);
     }
     const findMatchHighlightBorder = theme.getColor(editorFindMatchHighlightBorder);
     if (findMatchHighlightBorder) {
