@@ -31,7 +31,7 @@ import { registerThemingParticipant } from '../../../platform/theme/common/theme
 import { coalesce, flatten } from '../../../base/common/arrays.js';
 import { textLinkForeground } from '../../../platform/theme/common/colorRegistry.js';
 import { Widget } from '../../../base/browser/ui/widget.js';
-import { HoverWidget, renderHoverAction } from '../../../base/browser/ui/hover/hoverWidget.js';
+import { HoverWidget, HoverAction } from '../../../base/browser/ui/hover/hoverWidget.js';
 import { MarkerHoverParticipant } from './markerHoverParticipant.js';
 import { IInstantiationService } from '../../../platform/instantiation/common/instantiation.js';
 import { MarkdownHoverParticipant } from './markdownHoverParticipant.js';
@@ -54,8 +54,8 @@ let EditorHoverStatusBar = class EditorHoverStatusBar extends Disposable {
     addAction(actionOptions) {
         const keybinding = this._keybindingService.lookupKeybinding(actionOptions.commandId);
         const keybindingLabel = keybinding ? keybinding.getLabel() : null;
-        this._register(renderHoverAction(this.actionsElement, actionOptions, keybindingLabel));
         this._hasContent = true;
+        return this._register(HoverAction.render(this.actionsElement, actionOptions, keybindingLabel));
     }
     append(element) {
         const result = dom.append(this.actionsElement, element);
