@@ -36,6 +36,8 @@ import { isLowSurrogate, isHighSurrogate, getLeadingWhitespace } from '../../../
 import { IClipboardService } from '../../../platform/clipboard/common/clipboardService.js';
 import { ITelemetryService } from '../../../platform/telemetry/common/telemetry.js';
 import { ILogService } from '../../../platform/log/common/log.js';
+import { IContextKeyService } from '../../../platform/contextkey/common/contextkey.js';
+import { IConfigurationService } from '../../../platform/configuration/common/configuration.js';
 export class LineContext {
     constructor(model, position, auto, shy) {
         this.leadingLineContent = model.getLineContent(position.lineNumber).substr(0, position.column - 1);
@@ -65,13 +67,23 @@ export class LineContext {
         return true;
     }
 }
+function shouldPreventQuickSuggest(contextKeyService, configurationService) {
+    return (Boolean(contextKeyService.getContextKeyValue('inlineSuggestionVisible'))
+        && !Boolean(configurationService.getValue('editor.inlineSuggest.allowQuickSuggestions')));
+}
+function shouldPreventSuggestOnTriggerCharacters(contextKeyService, configurationService) {
+    return (Boolean(contextKeyService.getContextKeyValue('inlineSuggestionVisible'))
+        && !Boolean(configurationService.getValue('editor.inlineSuggest.allowSuggestOnTriggerCharacters')));
+}
 let SuggestModel = class SuggestModel {
-    constructor(_editor, _editorWorkerService, _clipboardService, _telemetryService, _logService) {
+    constructor(_editor, _editorWorkerService, _clipboardService, _telemetryService, _logService, _contextKeyService, _configurationService) {
         this._editor = _editor;
         this._editorWorkerService = _editorWorkerService;
         this._clipboardService = _clipboardService;
         this._telemetryService = _telemetryService;
         this._logService = _logService;
+        this._contextKeyService = _contextKeyService;
+        this._configurationService = _configurationService;
         this._toDispose = new DisposableStore();
         this._quickSuggestDelay = 10;
         this._triggerCharacterListener = new DisposableStore();
@@ -160,6 +172,9 @@ let SuggestModel = class SuggestModel {
             }
         }
         const checkTriggerCharacter = (text) => {
+            if (shouldPreventSuggestOnTriggerCharacters(this._contextKeyService, this._configurationService)) {
+                return;
+            }
             if (!text) {
                 // came here from the compositionEnd-event
                 const position = this._editor.getPosition();
@@ -281,6 +296,10 @@ let SuggestModel = class SuggestModel {
                         return;
                     }
                 }
+                if (shouldPreventQuickSuggest(this._contextKeyService, this._configurationService)) {
+                    // do not trigger quick suggestions if inline suggestions are shown
+                    return;
+                }
                 // we made it till here -> trigger now
                 this.trigger({ auto: true, shy: false });
             }, this._quickSuggestDelay);
@@ -579,6 +598,8 @@ SuggestModel = __decorate([
     __param(1, IEditorWorkerService),
     __param(2, IClipboardService),
     __param(3, ITelemetryService),
-    __param(4, ILogService)
+    __param(4, ILogService),
+    __param(5, IContextKeyService),
+    __param(6, IConfigurationService)
 ], SuggestModel);
 export { SuggestModel };
