@@ -25,6 +25,7 @@ import { Disposable } from '../../../base/common/lifecycle.js';
 import { registerEditorContribution } from '../../browser/editorExtensions.js';
 import { ICodeEditorService } from '../../browser/services/codeEditorService.js';
 import { IDialogService } from '../../../platform/dialogs/common/dialogs.js';
+import { basename } from '../../../base/common/resources.js';
 const ignoreUnusualLineTerminators = 'ignoreUnusualLineTerminators';
 function writeIgnoreState(codeEditorService, model, state) {
     codeEditorService.setModelProperty(model.uri, ignoreUnusualLineTerminators, state);
@@ -85,9 +86,9 @@ let UnusualLineTerminatorsDetector = class UnusualLineTerminatorsDetector extend
             const result = yield this._dialogService.confirm({
                 title: nls.localize('unusualLineTerminators.title', "Unusual Line Terminators"),
                 message: nls.localize('unusualLineTerminators.message', "Detected unusual line terminators"),
-                detail: nls.localize('unusualLineTerminators.detail', "This file contains one or more unusual line terminator characters, like Line Separator (LS) or Paragraph Separator (PS).\n\nIt is recommended to remove them from the file. This can be configured via `editor.unusualLineTerminators`."),
-                primaryButton: nls.localize('unusualLineTerminators.fix', "Fix this file"),
-                secondaryButton: nls.localize('unusualLineTerminators.ignore', "Ignore problem for this file")
+                detail: nls.localize('unusualLineTerminators.detail', "The file '{0}' contains one or more unusual line terminator characters, like Line Separator (LS) or Paragraph Separator (PS).\n\nIt is recommended to remove them from the file. This can be configured via `editor.unusualLineTerminators`.", basename(model.uri)),
+                primaryButton: nls.localize('unusualLineTerminators.fix', "Remove Unusual Line Terminators"),
+                secondaryButton: nls.localize('unusualLineTerminators.ignore', "Ignore")
             });
             if (!result.confirmed) {
                 // this model should be ignored
