@@ -130,7 +130,7 @@ class MultipleSelectionController extends Disposable {
 function toWorkbenchListOptions(options, configurationService, keybindingService) {
     const disposables = new DisposableStore();
     const result = Object.assign({}, options);
-    if (options.multipleSelectionSupport !== false && !options.multipleSelectionController) {
+    if (!options.multipleSelectionController) {
         const multipleSelectionController = new MultipleSelectionController(configurationService);
         result.multipleSelectionController = multipleSelectionController;
         disposables.add(multipleSelectionController);
@@ -151,8 +151,8 @@ let WorkbenchList = class WorkbenchList extends List {
         this.disposables.add(workbenchListOptionsDisposable);
         this.contextKeyService = createScopedContextKeyService(contextKeyService, this);
         this.themeService = themeService;
-        const listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
-        listSupportsMultiSelect.set(!(options.multipleSelectionSupport === false));
+        this.listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
+        this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
         const listSelectionNavigation = WorkbenchListSelectionNavigation.bindTo(this.contextKeyService);
         listSelectionNavigation.set(Boolean(options.selectionNavigation));
         this.listHasSelectionOrFocus = WorkbenchListHasSelectionOrFocus.bindTo(this.contextKeyService);
@@ -204,6 +204,9 @@ let WorkbenchList = class WorkbenchList extends List {
         if (options.overrideStyles) {
             this.updateStyles(options.overrideStyles);
         }
+        if (options.multipleSelectionSupport !== undefined) {
+            this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
+        }
     }
     updateStyles(styles) {
         var _a;
@@ -234,8 +237,8 @@ let WorkbenchPagedList = class WorkbenchPagedList extends PagedList {
         this.contextKeyService = createScopedContextKeyService(contextKeyService, this);
         this.themeService = themeService;
         this.horizontalScrolling = options.horizontalScrolling;
-        const listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
-        listSupportsMultiSelect.set(!(options.multipleSelectionSupport === false));
+        this.listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
+        this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
         const listSelectionNavigation = WorkbenchListSelectionNavigation.bindTo(this.contextKeyService);
         listSelectionNavigation.set(Boolean(options.selectionNavigation));
         this._useAltAsMultipleSelectionModifier = useAltAsMultipleSelectionModifier(configurationService);
@@ -272,6 +275,9 @@ let WorkbenchPagedList = class WorkbenchPagedList extends PagedList {
         if (options.overrideStyles) {
             this.updateStyles(options.overrideStyles);
         }
+        if (options.multipleSelectionSupport !== undefined) {
+            this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
+        }
     }
     updateStyles(styles) {
         var _a;
@@ -302,8 +308,8 @@ let WorkbenchTable = class WorkbenchTable extends Table {
         this.disposables.add(workbenchListOptionsDisposable);
         this.contextKeyService = createScopedContextKeyService(contextKeyService, this);
         this.themeService = themeService;
-        const listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
-        listSupportsMultiSelect.set(!(options.multipleSelectionSupport === false));
+        this.listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
+        this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
         const listSelectionNavigation = WorkbenchListSelectionNavigation.bindTo(this.contextKeyService);
         listSelectionNavigation.set(Boolean(options.selectionNavigation));
         this.listHasSelectionOrFocus = WorkbenchListHasSelectionOrFocus.bindTo(this.contextKeyService);
@@ -355,6 +361,9 @@ let WorkbenchTable = class WorkbenchTable extends Table {
         if (options.overrideStyles) {
             this.updateStyles(options.overrideStyles);
         }
+        if (options.multipleSelectionSupport !== undefined) {
+            this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
+        }
     }
     updateStyles(styles) {
         var _a;
@@ -502,6 +511,10 @@ let WorkbenchObjectTree = class WorkbenchObjectTree extends ObjectTree {
         this.internals = new WorkbenchTreeInternals(this, options, getAutomaticKeyboardNavigation, options.overrideStyles, contextKeyService, listService, themeService, configurationService, accessibilityService);
         this.disposables.add(this.internals);
     }
+    updateOptions(options) {
+        super.updateOptions(options);
+        this.internals.updateOptions(options);
+    }
 };
 WorkbenchObjectTree = __decorate([
     __param(5, IContextKeyService),
@@ -525,6 +538,7 @@ let WorkbenchCompressibleObjectTree = class WorkbenchCompressibleObjectTree exte
         if (options.overrideStyles) {
             this.internals.updateStyleOverrides(options.overrideStyles);
         }
+        this.internals.updateOptions(options);
     }
 };
 WorkbenchCompressibleObjectTree = __decorate([
@@ -549,6 +563,7 @@ let WorkbenchDataTree = class WorkbenchDataTree extends DataTree {
         if (options.overrideStyles) {
             this.internals.updateStyleOverrides(options.overrideStyles);
         }
+        this.internals.updateOptions(options);
     }
 };
 WorkbenchDataTree = __decorate([
@@ -574,6 +589,7 @@ let WorkbenchAsyncDataTree = class WorkbenchAsyncDataTree extends AsyncDataTree
         if (options.overrideStyles) {
             this.internals.updateStyleOverrides(options.overrideStyles);
         }
+        this.internals.updateOptions(options);
     }
 };
 WorkbenchAsyncDataTree = __decorate([
@@ -593,6 +609,10 @@ let WorkbenchCompressibleAsyncDataTree = class WorkbenchCompressibleAsyncDataTre
         this.internals = new WorkbenchTreeInternals(this, options, getAutomaticKeyboardNavigation, options.overrideStyles, contextKeyService, listService, themeService, configurationService, accessibilityService);
         this.disposables.add(this.internals);
     }
+    updateOptions(options) {
+        super.updateOptions(options);
+        this.internals.updateOptions(options);
+    }
 };
 WorkbenchCompressibleAsyncDataTree = __decorate([
     __param(7, IContextKeyService),
@@ -637,8 +657,8 @@ let WorkbenchTreeInternals = class WorkbenchTreeInternals {
         this.themeService = themeService;
         this.disposables = [];
         this.contextKeyService = createScopedContextKeyService(contextKeyService, tree);
-        const listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
-        listSupportsMultiSelect.set(!(options.multipleSelectionSupport === false));
+        this.listSupportsMultiSelect = WorkbenchListSupportsMultiSelectContextKey.bindTo(this.contextKeyService);
+        this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
         const listSelectionNavigation = WorkbenchListSelectionNavigation.bindTo(this.contextKeyService);
         listSelectionNavigation.set(Boolean(options.selectionNavigation));
         this.hasSelectionOrFocus = WorkbenchListHasSelectionOrFocus.bindTo(this.contextKeyService);
@@ -710,6 +730,11 @@ let WorkbenchTreeInternals = class WorkbenchTreeInternals {
         this.disposables.push(this.navigator);
     }
     get onDidOpen() { return this.navigator.onDidOpen; }
+    updateOptions(options) {
+        if (options.multipleSelectionSupport !== undefined) {
+            this.listSupportsMultiSelect.set(!!options.multipleSelectionSupport);
+        }
+    }
     updateStyleOverrides(overrideStyles) {
         dispose(this.styler);
         this.styler = overrideStyles ? attachListStyler(this.tree, this.themeService, overrideStyles) : Disposable.None;
