@@ -10,17 +10,19 @@
 // flowlint ambiguous-object-type:error
 'use strict';
 
-var invariant = require("fbjs/lib/invariant");
+var invariant = require('invariant');
 
 var _require = require('./RelayModernRecord'),
     getType = _require.getType;
 
-var REACT_FLIGHT_QUERIES_STORAGE_KEY = 'queries';
+// Reachable (client) executable definitions encountered while server component
+// rendering
+var REACT_FLIGHT_EXECUTABLE_DEFINITIONS_STORAGE_KEY = 'executableDefinitions';
 var REACT_FLIGHT_TREE_STORAGE_KEY = 'tree';
 var REACT_FLIGHT_TYPE_NAME = 'ReactFlightComponent';
 
 function refineToReactFlightPayloadData(payload) {
-  if (payload == null || typeof payload !== 'object' || !Array.isArray(payload.tree) || !Array.isArray(payload.queries)) {
+  if (payload == null || typeof payload !== 'object' || typeof payload.status !== 'string' || !Array.isArray(payload.tree) && payload.tree !== null || !Array.isArray(payload.queries) || !Array.isArray(payload.fragments) || !Array.isArray(payload.errors)) {
     return null;
   }
 
@@ -39,7 +41,7 @@ function getReactFlightClientResponse(record) {
 }
 
 module.exports = {
-  REACT_FLIGHT_QUERIES_STORAGE_KEY: REACT_FLIGHT_QUERIES_STORAGE_KEY,
+  REACT_FLIGHT_EXECUTABLE_DEFINITIONS_STORAGE_KEY: REACT_FLIGHT_EXECUTABLE_DEFINITIONS_STORAGE_KEY,
   REACT_FLIGHT_TREE_STORAGE_KEY: REACT_FLIGHT_TREE_STORAGE_KEY,
   REACT_FLIGHT_TYPE_NAME: REACT_FLIGHT_TYPE_NAME,
   getReactFlightClientResponse: getReactFlightClientResponse,
