@@ -12,14 +12,10 @@
 
 var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
 
-var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
+var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
 
 var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
 
-function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }
-
-function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
-
 var IRTransformer = require('../core/IRTransformer');
 
 var getLiteralArgumentValues = require('../core/getLiteralArgumentValues');
@@ -64,7 +60,7 @@ function matchTransform(context) {
 }
 
 function visitInlineFragment(node, state) {
-  return this.traverse(node, _objectSpread(_objectSpread({}, state), {}, {
+  return this.traverse(node, (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, state), {}, {
     parentType: node.typeCondition
   }));
 }
@@ -111,7 +107,7 @@ function visitLinkedField(node, state) {
   }
 
   state.path.push(node);
-  var transformedNode = this.traverse(node, _objectSpread(_objectSpread({}, state), {}, {
+  var transformedNode = this.traverse(node, (0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, state), {}, {
     moduleKey: moduleKey,
     parentType: node.type
   }));
@@ -422,7 +418,7 @@ function visitFragmentSpread(spread, _ref2) {
       module: moduleName,
       sourceDocument: documentName,
       name: spread.name,
-      selections: [_objectSpread(_objectSpread({}, spread), {}, {
+      selections: [(0, _objectSpread2["default"])((0, _objectSpread2["default"])({}, spread), {}, {
         directives: spread.directives.filter(function (directive) {
           return directive !== moduleDirective;
         })
